@@ -1,4 +1,4 @@
-/* */
+/* $Id: cmsprf.c,v 1.8 2006/02/19 23:59:13 hvengel Exp $ */
 /*  Little cms - profiler construction set */
 /*  Copyright (C) 1998-2001 Marti Maria */
 /* */
@@ -416,8 +416,9 @@ BOOL cmsxChoosePCS(LPPROFILERCOMMONDATA hdr)
 
         }
         else {
-  
-                hdr ->PCSType = PT_XYZ;
+                // hdr ->PCSType = PT_XYZ;
+		// XXX fuer
+                hdr ->PCSType = PT_Lab;
 
                 if (hdr ->cmsprintf)
                        hdr ->cmsprintf("I have choosen XYZ as PCS");                        
